@@ -1,17 +1,10 @@
 # -*- coding: utf-8 -*-
-# vim: autoindent shiftwidth=4 expandtab textwidth=80 tabstop=4 softtabstop=4
+# vim: autoindent shiftwidth=4 expandtab textwidth=120 tabstop=4 softtabstop=4
 
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
-# Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
-# Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
-# Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
-# Christian Richter, Philip Ridout, Simon Scudder, Jeffrey Smith,             #
-# Maikel Stuivenberg, Martin Thompson, Jon Tibble, Dave Warnock,              #
-# Frode Woldsund, Martin Zibricky                                             #
+# Copyright (c) 2008-2016 OpenLP Developers                                   #
 # --------------------------------------------------------------------------- #
 # This program is free software; you can redistribute it and/or modify it     #
 # under the terms of the GNU General Public License as published by the Free  #
@@ -50,11 +43,13 @@ from lxml import etree, objectify
 
 log = logging.getLogger(__name__)
 
+
+# TODO: These classes need to be refactored into a single class.
 class CustomXMLBuilder(object):
     """
     This class builds the XML used to describe songs.
     """
-    log.info(u'CustomXMLBuilder Loaded')
+    log.info('CustomXMLBuilder Loaded')
 
     def __init__(self):
         """
@@ -62,15 +57,17 @@ class CustomXMLBuilder(object):
         """
         # Create the minidom document
         self.custom_xml = Document()
+        self.new_document()
+        self.add_lyrics_to_song()
 
     def new_document(self):
         """
         Create a new custom XML document.
         """
         # Create the <song> base element
-        self.song = self.custom_xml.createElement(u'song')
+        self.song = self.custom_xml.createElement('song')
         self.custom_xml.appendChild(self.song)
-        self.song.setAttribute(u'version', u'1.0')
+        self.song.setAttribute('version', '1.0')
 
     def add_lyrics_to_song(self):
         """
@@ -78,27 +75,23 @@ class CustomXMLBuilder(object):
         custom item.
         """
         # Create the main <lyrics> element
-        self.lyrics = self.custom_xml.createElement(u'lyrics')
-        self.lyrics.setAttribute(u'language', u'en')
+        self.lyrics = self.custom_xml.createElement('lyrics')
+        self.lyrics.setAttribute('language', 'en')
         self.song.appendChild(self.lyrics)
 
-    def add_verse_to_lyrics(self, type, number, content):
+    def add_verse_to_lyrics(self, verse_type, number, content):
         """
         Add a verse to the ``<lyrics>`` tag.
 
-        ``type``
-            A string denoting the type of verse. Possible values are "Chorus",
-            "Verse", "Bridge", and "Custom".
+        :param verse_type: A string denoting the type of verse. Possible values are "Chorus", "Verse", "Bridge",
+            and "Custom".
+        :param number:  An integer denoting the number of the item, for example: verse 1.
+        :param content: The actual text of the verse to be stored.
 
-        ``number``
-            An integer denoting the number of the item, for example: verse 1.
-
-        ``content``
-            The actual text of the verse to be stored.
         """
-        verse = self.custom_xml.createElement(u'verse')
-        verse.setAttribute(u'type', type)
-        verse.setAttribute(u'label', number)
+        verse = self.custom_xml.createElement('verse')
+        verse.setAttribute('type', verse_type)
+        verse.setAttribute('label', number)
         self.lyrics.appendChild(verse)
         # add data as a CDATA section to protect the XML from special chars
         cds = self.custom_xml.createCDATASection(content)
@@ -108,48 +101,46 @@ class CustomXMLBuilder(object):
         """
         Debugging aid to dump XML so that we can see what we have.
         """
-        return self.custom_xml.toprettyxml(indent=u'  ')
+        return self.custom_xml.toprettyxml(indent='  ')
 
     def extract_xml(self):
         """
         Extract our newly created XML custom.
         """
-        return self.custom_xml.toxml(u'utf-8')
+        return self.custom_xml.toxml('utf-8')
 
 
 class CustomXMLParser(object):
     """
     A class to read in and parse a custom's XML.
     """
-    log.info(u'CustomXMLParser Loaded')
+    log.info('CustomXMLParser Loaded')
 
     def __init__(self, xml):
         """
         Set up our custom XML parser.
 
-        ``xml``
-            The XML of the custom to be parsed.
+        :param xml: The XML of the custom to be parsed.
         """
         self.custom_xml = None
-        if xml[:5] == u'<?xml':
+        if xml[:5] == '<?xml':
             xml = xml[38:]
         try:
             self.custom_xml = objectify.fromstring(xml)
         except etree.XMLSyntaxError:
-            log.exception(u'Invalid xml %s', xml)
+            log.exception('Invalid xml %s', xml)
 
     def get_verses(self):
         """
-        Iterates through the verses in the XML and returns a list of verses
-        and their attributes.
+        Iterates through the verses in the XML and returns a list of verses and their attributes.
         """
         xml_iter = self.custom_xml.getiterator()
         verse_list = []
         for element in xml_iter:
-            if element.tag == u'verse':
+            if element.tag == 'verse':
                 if element.text is None:
-                    element.text = u''
-                verse_list.append([element.attrib, unicode(element.text)])
+                    element.text = ''
+                verse_list.append([element.attrib, str(element.text)])
         return verse_list
 
     def _dump_xml(self):
